/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import type { OperationOptions } from "retry";
export declare namespace Orders {
  type ErrorResponse = {
    type: string;
    title?: string;
    detail?: string;
    instance?: string;
  } & {
    [key: string]: any;
  };
  type PaymentTransactionUpdateRequest = {} & {
    [key: string]: any;
  };
  type PaymentInstrumentUpdateRequest = {} & {
    [key: string]: any;
  };
  type OrderPaymentStatusUpdateRequest = {
    status: string;
  };
  type PaymentCard = {
    cardType?: string;
    creditCardExpired?: boolean;
    creditCardToken?: string;
    expirationMonth?: number;
    expirationYear?: number;
    holder?: string;
    issueNumber?: string;
    maskedNumber?: string;
    numberLastDigits?: string;
    validFromMonth?: number;
    validFromYear?: number;
  };
  type ShippingItem = {
    basePrice?: number;
    grossPrice?: number;
    itemText?: string;
    netPrice?: number;
    tax?: number;
    taxBasis?: number;
    adjustedTax?: number;
    itemId?: string;
    priceAdjustments?: Array<PriceAdjustment>;
    priceAfterItemDiscount?: number;
    shipmentId?: string;
    taxRate: number;
    type?: string;
  } & {
    [key: string]: any;
  };
  type Discount = {
    amount?: number;
    percentage?: number;
    priceBookId?: string;
    type: string;
  };
  type OrderConfirmationStatusUpdateRequest = {
    status: string;
  };
  type Address = {
    address1?: string;
    address2?: string;
    city?: string;
    companyName?: string;
    countryCode?: string;
    firstName?: string;
    fullName?: string;
    jobTitle?: string;
    lastName?: string;
    phone?: string;
    postBox?: string;
    postalCode?: string;
    salutation?: string;
    secondName?: string;
    stateCode?: string;
    suffix?: string;
    suite?: string;
    title?: string;
  } & {
    [key: string]: any;
  };
  type CouponItem = {
    code?: string;
    couponItemId?: string;
    statusCode?: string;
    valid?: boolean;
  };
  type OrdersResponse = {
    data: Array<Order>;
  };
  type ShippingMethodReference = {
    id?: string;
  };
  type ProductItem = {
    basePrice?: number;
    grossPrice?: number;
    itemText?: string;
    netPrice?: number;
    tax?: number;
    taxBasis?: number;
    adjustedTax?: number;
    bonusDiscountLineItemId?: string;
    bonusProductLineItem?: boolean;
    brand?: string;
    bundledProductItems?: Array<ProductItem>;
    externalLineItemStatus?: string;
    externalLineItemText?: string;
    gift?: boolean;
    giftMessage?: string;
    inventoryId?: string;
    itemId?: string;
    minOrderQuantity?: number;
    optionItems?: Array<OptionItem>;
    position?: number;
    priceAdjustments?: Array<PriceAdjustment>;
    priceAfterItemDiscount?: number;
    priceAfterOrderDiscount?: number;
    productId: string;
    productListItem?: ProductListItemReference;
    productName?: string;
    quantity?: number;
    shipmentId: string;
    shippingItemId?: string;
    stepQuantity?: number;
    taxRate: number;
  } & {
    [key: string]: any;
  };
  type BonusDiscountLineItem = {
    bonusProducts?: Array<ProductReference>;
    couponCode?: string;
    id?: string;
    maxBonusItems?: number;
    promotionId?: string;
  } & {
    [key: string]: any;
  };
  type ShippingAddressUpdateRequest = {} & {
    [key: string]: any;
  };
  type Shipment = {
    adjustedMerchandizeTotalTax?: number;
    adjustedShippingTotalTax?: number;
    gift?: boolean;
    giftMessage?: string;
    merchandizeTotalTax?: number;
    productSubTotal?: number;
    productTotal?: number;
    shipmentId: string;
    shipmentNo: string;
    shipmentTotal?: number;
    shippingAddress?: Address;
    shippingMethod?: ShippingMethodReference;
    shippingStatus?: string;
    shippingTotal?: number;
    shippingTotalTax?: number;
    taxTotal?: number;
    trackingNumber?: string;
  } & {
    [key: string]: any;
  };
  type CustomerInfo = {
    customerId?: string;
    customerName?: string;
    customerNo?: string;
    email?: string;
    guest?: boolean;
  };
  type PriceAdjustment = {
    basePrice?: number;
    grossPrice?: number;
    itemText?: string;
    netPrice?: number;
    tax?: number;
    taxBasis?: number;
    abTestSegment?: ABTestSegment;
    appliedDiscount?: Discount;
    campaignId?: string;
    couponCode?: string;
    createdBy?: string;
    creationDate?: any;
    custom?: boolean;
    lastModified?: any;
    manual?: boolean;
    priceAdjustmentId?: string;
    promotionId: string;
    reasonCode?: string;
  } & {
    [key: string]: any;
  };
  type OrderExternalStatusUpdateRequest = {
    status: string;
  };
  type OptionItem = {
    basePrice?: number;
    grossPrice?: number;
    gift?: boolean;
    itemText?: string;
    netPrice?: number;
    tax?: number;
    taxBasis?: number;
    optionId?: string;
    optionValueId?: string;
    priceAdjustments?: Array<PriceAdjustment>;
    productId: string;
  } & {
    [key: string]: any;
  };
  type OrderShippingStatusUpdateRequest = {
    status: string;
  };
  type OrderUpdateRequest = {} & {
    [key: string]: any;
  };
  type ABTestSegment = {
    testId: string;
    segmentId: string;
  };
  type OrderNote = {
    createdBy?: string;
    creationDate?: any;
    subject?: string;
    text?: string;
  };
  type PaymentInstrument = {
    bankRoutingNumber?: string;
    maskedGiftCertificateCode?: string;
    paymentCard?: PaymentCard;
    paymentInstrumentId?: string;
    paymentMethodId?: string;
    paymentTransaction?: PaymentTransaction;
  } & {
    [key: string]: any;
  };
  type OrderExportStatusUpdateRequest = {
    status: string;
  };
  type OrderStatusUpdateRequest = {
    status: string;
  };
  type ProductReference = {
    productId?: string;
    productName?: string;
  };
  type GiftCertificateItem = {
    basePrice?: number;
    grossPrice?: number;
    itemText?: string;
    netPrice?: number;
    tax?: number;
    taxBasis?: number;
    giftCertificateMerchantId?: string;
    giftCertificateItemId?: string;
    message?: string;
    recipientEmail?: string;
    recipientName?: string;
    senderName?: string;
    shipmentId?: string;
  } & {
    [key: string]: any;
  };
  type PaymentTransaction = {
    amount?: number;
    authorizationStatus?: Status;
    transactionId?: string;
  } & {
    [key: string]: any;
  };
  type Order = {
    adjustedMerchandizeTotalTax?: number;
    adjustedShippingTotalTax?: number;
    affiliatePartnerId?: string;
    affiliatePartnerName?: string;
    billingAddress?: Address;
    bonusDiscountLineItems?: Array<BonusDiscountLineItem>;
    businessType?: string;
    cancelCode?: string;
    cancelDescription?: string;
    channelType?: string;
    confirmationStatus?: string;
    couponItems?: Array<CouponItem>;
    createdBy?: string;
    creationDate?: any;
    currency?: string;
    customerInfo?: CustomerInfo;
    customerLocale?: string;
    customerOrderReference?: string;
    exportStatus?: string;
    externalOrderNo?: string;
    externalOrderStatus?: string;
    externalOrderText?: string;
    giftCertificateItems?: Array<GiftCertificateItem>;
    globalPartyId?: string;
    invoiceNo?: string;
    lastModified?: any;
    merchandizeTotalTax?: number;
    notes?: Array<OrderNote>;
    orderNo: string;
    orderPriceAdjustments?: Array<PriceAdjustment>;
    orderTotal?: number;
    paymentInstruments?: Array<PaymentInstrument>;
    paymentStatus?: string;
    placeDate?: any;
    productItems?: Array<ProductItem>;
    productSubTotal?: number;
    productTotal?: number;
    remoteHost?: string;
    shipments?: Array<Shipment>;
    shippingItems?: Array<ShippingItem>;
    shippingStatus?: string;
    shippingTotal?: number;
    shippingTotalTax?: number;
    siteId?: string;
    sourceCode?: string;
    sourceCodeGroupId?: string;
    status?: string;
    taxTotal?: number;
    taxation?: string;
  } & {
    [key: string]: any;
  };
  type ProductListReference = {
    description?: string;
    name?: string;
    public?: boolean;
    type?: string;
  };
  type Status = {
    code?: string;
    message?: string;
    status?: number;
  };
  type ProductListItemReference = {
    id?: string;
    priority?: number;
    product?: ProductReference;
    productList?: ProductListReference;
    public?: boolean;
    purchasedQuantity: number;
    quantity?: number;
    type?: string;
  };
  type Money = {
    currencyMnemonic?: string;
    value?: number;
  } & {
    [key: string]: any;
  };
  type SimpleSearchResult = {
    limit: number;
    hits?: Array<object>;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type SearchRequest = {
    limit?: number;
    query: any;
    sorts?: Array<Sort>;
    offset?: number;
  } & {
    [key: string]: any;
  };
  type PaginatedSearchResult = {
    query: any;
    sorts?: Array<Sort>;
    limit: number;
    hits?: Array<object>;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type ClosedObject = {} & {
    [key: string]: any;
  };
  type OpenObject = {} & {
    [key: string]: any;
  };
  type NoPropertiesAllowed = {};
  type SpecifiedPropertiesAllowed = {} & {
    [key: string]: any;
  };
  type BoolFilter = {
    filters?: Array<any>;
    operator: string;
  } & {
    [key: string]: any;
  };
  type PaginatedSearchResultBase = {
    query: any;
    sorts?: Array<Sort>;
    limit: number;
    hits?: Array<object>;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type MatchAllQuery = {} & {
    [key: string]: any;
  };
  type FilteredQuery = {
    filter: any;
    query: any;
  } & {
    [key: string]: any;
  };
  type QueryFilter = {
    query: any;
  } & {
    [key: string]: any;
  };
  type Query = {
    boolQuery?: BoolQuery;
    filteredQuery?: FilteredQuery;
    matchAllQuery?: MatchAllQuery;
    nestedQuery?: NestedQuery;
    termQuery?: TermQuery;
    textQuery?: TextQuery;
  } & {
    [key: string]: any;
  };
  type TermQuery = {
    fields: Array<string>;
    operator: string;
    values?: Array<any>;
  } & {
    [key: string]: any;
  };
  type TermFilter = {
    field: string;
    operator: string;
    values?: Array<any>;
  } & {
    [key: string]: any;
  };
  type TextQuery = {
    fields: Array<string>;
    searchPhrase: string;
  } & {
    [key: string]: any;
  };
  type Range2Filter = {
    filterMode?: string;
    fromField: string;
    fromInclusive?: boolean;
    fromValue?: any;
    toField: string;
    toInclusive?: boolean;
    toValue?: any;
  } & {
    [key: string]: any;
  };
  type BoolQuery = {
    must?: Array<any>;
    mustNot?: Array<any>;
    should?: Array<any>;
  } & {
    [key: string]: any;
  };
  type SimpleSearchResultBase = {
    limit: number;
    hits?: Array<object>;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type NestedQuery = {
    path: string;
    query: any;
    scoreMode?: string;
  } & {
    [key: string]: any;
  };
  type Filter = {
    boolFilter?: BoolFilter;
    queryFilter?: QueryFilter;
    range2Filter?: Range2Filter;
    rangeFilter?: RangeFilter;
    termFilter?: TermFilter;
  } & {
    [key: string]: any;
  };
  type Sort = {
    field: string;
    sortOrder?: string;
  } & {
    [key: string]: any;
  };
  type RangeFilter = {
    field: string;
    from?: any;
    fromInclusive?: boolean;
    to?: any;
    toInclusive?: boolean;
  } & {
    [key: string]: any;
  };
  type SearchRequestBase = {
    limit?: number;
    query: any;
    sorts?: Array<Sort>;
    offset?: number;
  } & {
    [key: string]: any;
  };
  type MoneyMnemonic = {
    currencyMnemonic?: string;
    value?: number;
  } & {
    [key: string]: any;
  };
  type ChangeControlled = {
    creationDate?: any;
    modificationDate?: any;
    createdBy?: string;
    lastModifiedBy?: string;
  } & {
    [key: string]: any;
  };
  type ChangeControlledDataType = {
    creationDate?: any;
    modificationDate?: any;
    createdBy?: string;
    lastModifiedBy?: string;
  } & {
    [key: string]: any;
  };
  type Error = {
    type: string;
    title?: string;
    detail?: string;
    instance?: string;
  } & {
    [key: string]: any;
  };
}
/**
* [Orders](https://developer.salesforce.com/docs/commerce/commerce-api/references?meta=orders:Summary)
* ==================================
*
* *Manage order and order payment status.*<br />
*
* Simple example:
*
* ```typescript
*   import { Checkout, ClientConfig } from "commerce-sdk";
*   // or
*   const { Checkout, ClientConfig } = require("commerce-sdk");
*
*   const clientConfig: ClientConfig = { ... };
*   const ordersClient = new Checkout.Orders(clientConfig);
* ```
*
* Example with shopper auth
* ```typescript
* const clientConfig: ClientConfig = {
*   parameters: {
*     clientId: "XXXXXX",
*     organizationId: "XXXX",
*     shortCode: "XXX",
*     siteId: "XX"
*   }
* };
* token = await helpers.getShopperToken(clientConfig, { type: "guest" });
* clientConfig.headers["authorization"] = token.getBearerHeader();
* const ordersClient = new Checkout.Orders(clientConfig);
* ```
*
* <span style="font-size:.7em; display:block; text-align: right">
* API Version: 1.2.0<br />
* Last Updated: <br />
* </span>

*

*/
export declare class Orders extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Returns the details of orders that match the query filters. By default, calling this API with no filter returns the 100 most recently created orders. To return up to 1000 orders, use the limit parameter. To return a page of results past the first page, use a resource offset.
   *
   * If you would like to get a raw Response object use the other getOrders function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param sortBy - Sort results by creation date or last modified date. The default is creation date.
   * @param sortOrder - Sort results in ascending or descending order. The default is descending.
   * @param status - Filter results by status. Valid statuses are 'new', 'completed', and 'cancelled'. You can include up to two statuses as a comma-separated string.
   * @param exportStatus - Filter results by export status. Valid export statuses are 'not_exported', 'exported', 'ready', and 'failed'. You can include up to three export statuses as a comma-separated string.
   * @param externalStatus - Filter results by external status.
   * @param confirmationStatus - Filter results by confirmation status. Valid confirmation statuses are 'confirmed' and 'not_confirmed'.
   * @param paymentStatus - Filter results by payment status. Valid payment statuses are 'not_paid', 'part_paid', and 'paid'. You can include up to two payment statuses as a comma-separated string.
   * @param shippingStatus - Filter results by shipping status. Valid shipping statuses are 'not_shipped', 'part_shipped', and 'shipped'. You can include up to two shipping statuses as a comma-separated string.
   * @param siteId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 200. Defaults to 100.
   * @param creationDateFrom - If passed, will return records where the `creationDate` is equal to or greater than the passed `datetime`.
   * @param creationDateTo - If passed, will return records where the `creationDate` is less than the passed `datetime`.
   * @param lastModifiedDateFrom - If passed, will return records where the `lastModifiedDate` is equal to or greater than the passed `datetime`.
   * @param lastModifiedDateTo - If passed, will return records where the `lastModifiedDate` is less than the passed `datetime`.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type Orders.OrdersResponse.
   *
   */
  getOrders(options?: {
    parameters?: {
      organizationId?: string;
      sortBy?: string;
      sortOrder?: string;
      status?: string;
      exportStatus?: string;
      externalStatus?: string;
      confirmationStatus?: string;
      paymentStatus?: string;
      shippingStatus?: string;
      siteId?: string;
      offset?: any;
      limit?: number;
      creationDateFrom?: any;
      creationDateTo?: any;
      lastModifiedDateFrom?: any;
      lastModifiedDateTo?: any;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<Orders.OrdersResponse>;
  /**
   * Returns the details of orders that match the query filters. By default, calling this API with no filter returns the 100 most recently created orders. To return up to 1000 orders, use the limit parameter. To return a page of results past the first page, use a resource offset.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param sortBy - Sort results by creation date or last modified date. The default is creation date.
   * @param sortOrder - Sort results in ascending or descending order. The default is descending.
   * @param status - Filter results by status. Valid statuses are 'new', 'completed', and 'cancelled'. You can include up to two statuses as a comma-separated string.
   * @param exportStatus - Filter results by export status. Valid export statuses are 'not_exported', 'exported', 'ready', and 'failed'. You can include up to three export statuses as a comma-separated string.
   * @param externalStatus - Filter results by external status.
   * @param confirmationStatus - Filter results by confirmation status. Valid confirmation statuses are 'confirmed' and 'not_confirmed'.
   * @param paymentStatus - Filter results by payment status. Valid payment statuses are 'not_paid', 'part_paid', and 'paid'. You can include up to two payment statuses as a comma-separated string.
   * @param shippingStatus - Filter results by shipping status. Valid shipping statuses are 'not_shipped', 'part_shipped', and 'shipped'. You can include up to two shipping statuses as a comma-separated string.
   * @param siteId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 200. Defaults to 100.
   * @param creationDateFrom - If passed, will return records where the `creationDate` is equal to or greater than the passed `datetime`.
   * @param creationDateTo - If passed, will return records where the `creationDate` is less than the passed `datetime`.
   * @param lastModifiedDateFrom - If passed, will return records where the `lastModifiedDate` is equal to or greater than the passed `datetime`.
   * @param lastModifiedDateTo - If passed, will return records where the `lastModifiedDate` is less than the passed `datetime`.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type Orders.OrdersResponse otherwise.
   *
   */
  getOrders<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        sortBy?: string;
        sortOrder?: string;
        status?: string;
        exportStatus?: string;
        externalStatus?: string;
        confirmationStatus?: string;
        paymentStatus?: string;
        shippingStatus?: string;
        siteId?: string;
        offset?: any;
        limit?: number;
        creationDateFrom?: any;
        creationDateTo?: any;
        lastModifiedDateFrom?: any;
        lastModifiedDateTo?: any;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : Orders.OrdersResponse>;
  /**
   * Returns the details of the order with the specified order number.
   *
   * If you would like to get a raw Response object use the other getOrder function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type Orders.Order.
   *
   */
  getOrder(options?: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<Orders.Order>;
  /**
   * Returns the details of the order with the specified order number.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type Orders.Order otherwise.
   *
   */
  getOrder<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : Orders.Order>;
  /**
   * Updates the order.
   *
   * If you would like to get a raw Response object use the other updateOrder function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   *
   */
  updateOrder(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Orders.OrderUpdateRequest;
  }): Promise<void>;
  /**
   * Updates the order.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  updateOrder<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Orders.OrderUpdateRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Updates the order confirmation status.
   *
   * If you would like to get a raw Response object use the other updateOrderConfirmationStatus function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   *
   */
  updateOrderConfirmationStatus(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Orders.OrderConfirmationStatusUpdateRequest;
  }): Promise<void>;
  /**
   * Updates the order confirmation status.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  updateOrderConfirmationStatus<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Orders.OrderConfirmationStatusUpdateRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Updates the order export status. If on-order inventory is turned on for the associated inventory list, then setting the export status to EXPORTED finalizes on-order inventory transactions for this order by changing their type from on-order to final.
   *
   * If you would like to get a raw Response object use the other updateOrderExportStatus function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   *
   */
  updateOrderExportStatus(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Orders.OrderExportStatusUpdateRequest;
  }): Promise<void>;
  /**
   * Updates the order export status. If on-order inventory is turned on for the associated inventory list, then setting the export status to EXPORTED finalizes on-order inventory transactions for this order by changing their type from on-order to final.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  updateOrderExportStatus<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Orders.OrderExportStatusUpdateRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Updates the order external status.
   *
   * If you would like to get a raw Response object use the other updateOrderExternalStatus function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   *
   */
  updateOrderExternalStatus(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Orders.OrderExternalStatusUpdateRequest;
  }): Promise<void>;
  /**
   * Updates the order external status.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  updateOrderExternalStatus<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Orders.OrderExternalStatusUpdateRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Updates the order payment status.
   *
   * If you would like to get a raw Response object use the other updateOrderPaymentStatus function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   *
   */
  updateOrderPaymentStatus(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Orders.OrderPaymentStatusUpdateRequest;
  }): Promise<void>;
  /**
   * Updates the order payment status.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  updateOrderPaymentStatus<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Orders.OrderPaymentStatusUpdateRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Updates the order shipping status.
   *
   * If you would like to get a raw Response object use the other updateOrderShippingStatus function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   *
   */
  updateOrderShippingStatus(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Orders.OrderShippingStatusUpdateRequest;
  }): Promise<void>;
  /**
   * Updates the order shipping status.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  updateOrderShippingStatus<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Orders.OrderShippingStatusUpdateRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
    * Updates the order status. Orders in status NEW, COMPLETED or CANCELLED can't be changed to status CREATED or FAILED.

Changing the status processes different actions on inventory, coupons, wishlists and the order itself. Here are the supported actions:

Fail Order: Release inventory and remove coupon redemptions. (CREATED -\> FAILED)
Undo Fail Order: Reserve inventory and recreate coupon redemptions. (FAILED -\> CREATED)
Place Order: Generate Shipment and Invoice numbers. (CREATED -\> NEW, COMPLETED or CANCELLED)
Cancel Order: Release inventory, remove wishlist purchases, and remove coupon redemptions. (NEW, COMPLETED -\> CANCELLED)
Undo Cancel Order: Reserve inventory, add wishlist purchases, and recreate coupon redemptions. (CANCELLED -\> NEW, COMPLETED)

Actions can fail for example when inventory is not available anymore.
    *
    * If you would like to get a raw Response object use the other updateOrderStatus function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
  updateOrderStatus(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Orders.OrderStatusUpdateRequest;
  }): Promise<void>;
  /**
    * Updates the order status. Orders in status NEW, COMPLETED or CANCELLED can't be changed to status CREATED or FAILED.

Changing the status processes different actions on inventory, coupons, wishlists and the order itself. Here are the supported actions:

Fail Order: Release inventory and remove coupon redemptions. (CREATED -\> FAILED)
Undo Fail Order: Reserve inventory and recreate coupon redemptions. (FAILED -\> CREATED)
Place Order: Generate Shipment and Invoice numbers. (CREATED -\> NEW, COMPLETED or CANCELLED)
Cancel Order: Release inventory, remove wishlist purchases, and remove coupon redemptions. (NEW, COMPLETED -\> CANCELLED)
Undo Cancel Order: Reserve inventory, add wishlist purchases, and recreate coupon redemptions. (CANCELLED -\> NEW, COMPLETED)

Actions can fail for example when inventory is not available anymore.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
  updateOrderStatus<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Orders.OrderStatusUpdateRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Updates the payment instrument of an order.
   *
   * If you would like to get a raw Response object use the other updateOrderPaymentInstrument function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param paymentInstrumentId - ID of the payment instrument.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   *
   */
  updateOrderPaymentInstrument(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      paymentInstrumentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Orders.PaymentInstrumentUpdateRequest;
  }): Promise<void>;
  /**
   * Updates the payment instrument of an order.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param paymentInstrumentId - ID of the payment instrument.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  updateOrderPaymentInstrument<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        paymentInstrumentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Orders.PaymentInstrumentUpdateRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Updates the transaction of an order payment instrument.
   *
   * If you would like to get a raw Response object use the other updateOrderPaymentTransaction function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param paymentInstrumentId - ID of the payment instrument.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   *
   */
  updateOrderPaymentTransaction(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      paymentInstrumentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Orders.PaymentTransactionUpdateRequest;
  }): Promise<void>;
  /**
   * Updates the transaction of an order payment instrument.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param paymentInstrumentId - ID of the payment instrument.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  updateOrderPaymentTransaction<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        paymentInstrumentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Orders.PaymentTransactionUpdateRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Creates or replaces the shipping address.
   *
   * If you would like to get a raw Response object use the other updateOrderShippingAddress function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param shipmentId - ID of the shipment.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   *
   */
  updateOrderShippingAddress(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      shipmentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Orders.ShippingAddressUpdateRequest;
  }): Promise<void>;
  /**
   * Creates or replaces the shipping address.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number.
   * @param shipmentId - ID of the shipment.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  updateOrderShippingAddress<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        shipmentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Orders.ShippingAddressUpdateRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
}
